@@ -19,10 +19,9 @@
 ######################################################
 
 """
-High level interfaces to a BioSignalML repository.
-
-This package simplifies creating and reading signals in a repository
-by providing wrappers around connections to metadata and data endpoints.
+The ``biosignalml.client`` package provides high-level interfaces to a
+BioSignalML repository, allowing recordings, signals and associated resources
+to be stored and retrieved.
 
 To create a new recording and signals::
 
@@ -86,15 +85,19 @@ from biosignalml            import BSML
 from biosignalml.data       import TimeSeries, UniformTimeSeries, DataSegment
 from biosignalml.data.time  import Interval
 from biosignalml.formats    import BSMLRecording, BSMLSignal, MIMETYPES
-from biosignalml.transports import StreamException
-from biosignalml.transports import BlockType, SignalData
 from biosignalml.transports import WebStreamReader, WebStreamWriter, StreamException
+from biosignalml.transports.stream import BlockType, SignalData
+
 
 from . import repository
 
 
+__all__ = [ 'Repository', 'Recording', 'Signal' ]
+
+
 class Signal(BSMLSignal):
 #========================
+  """A Signal in a :class:`Recording`."""
 
   def __init__(self, uri, units=None, **kwds):
   #-------------------------------------------
@@ -103,11 +106,6 @@ class Signal(BSMLSignal):
     super(Signal, self).__init__(uri, units, **kwds)
     self.repository = repository
 
-  def close(self):
-  #---------------
-    # Ensure all metadata has been POSTed
-    pass
-
   def __len__(self):
   #----------------
     return self._length
@@ -135,13 +133,13 @@ class Signal(BSMLSignal):
       if sd.rate is not None: yield DataSegment(sd.start, UniformTimeSeries(sd.data, sd.rate))
       else:                   yield DataSegment(sd.start, TimeSeries(sd.data, sd.clock))
 
-  def append(self, timeseries):
-  #----------------------------
+  def append(self, timeseries, dtype='f4'):
+  #----------------------------------------
     self._length += len(timeseries)
     if isinstance(timeseries, TimeSeries):
-      return self.repository.put_data(str(self.uri), timeseries)
+      return self.repository.put_data(str(self.uri), timeseries, dtype=dtype)
     elif self.rate:
-      return self.repository.put_data(str(self.uri), UniformTimeSeries(timeseries, self.rate))
+      return self.repository.put_data(str(self.uri), UniformTimeSeries(timeseries, self.rate), dtype=dtype)
 
 
 class Recording(BSMLRecording):
@@ -158,7 +156,13 @@ class Recording(BSMLRecording):
   def close(self):
   #---------------
     # Ensure all metadata has been POSTed
+#    logging.debug("Close recording: %s", self.metadata_as_string(format=rdf.Format.TURTLE))
     self.repository.post_metadata(self.uri, self.metadata_as_string())
+#    for sig in self.signals():
+#      self.repository.post_metadata(sig.uri, sig.metadata_as_string())
+
+    ## POST duplicates duration but leaves dataset...
+    ## PUT removes dataset,,,
 
   def add_signal(self, signal):
   #----------------------------
@@ -172,8 +176,6 @@ class Recording(BSMLRecording):
     # it will create an signal group in HDF5 container
     try:
       sig = super(Recording, self).new_signal(uri, units, id=id, repository=self.repository, **kwds)
-      ## This should spot duplicates
-
       #logging.debug('New Signal: %s --> %s', sig.uri, sig.attributes)
       self.repository.post_metadata(self.uri, sig.metadata_as_string())
       return sig
@@ -190,6 +192,9 @@ class Recording(BSMLRecording):
 class Repository(repository.RemoteRepository):
 #=============================================
 
+  ## Can a Repository by stateless, created on-the-fly as needed??
+  ## Then get/new methods would be static
+
   RecordingClass = Recording      #: The class of recordings in the repository.
 
   def __init__(self, uri, name=None, password=None, **kwds):
@@ -258,13 +263,13 @@ class Repository(repository.RemoteRepository):
       if block.type == BlockType.DATA: yield block.signaldata()
     reader.join()
 
-  def put_data(self, uri, timeseries):
-  #-----------------------------------
+  def put_data(self, uri, timeseries, dtype='f4'):
+  #-----------------------------------------------
     stream = None
     try:
       stream = WebStreamWriter(self._web_sockets_uri(uri), token=self.access_token)
       MAXPOINTS = 10000
-      params = { 'dtype': 'f4' }
+      params = { 'dtype': dtype }
       if hasattr(timeseries, 'rate'): params['rate'] = timeseries.rate
       pos = 0
       count = len(timeseries)
