@@ -139,6 +139,8 @@ import urllib
 import h5py
 import numpy as np
 
+__all__ = [ 'H5Clock', 'H5Signal', 'H5Recording', 'IDENTIFIER' ]
+
 
 MAJOR      = 1
 MINOR      = 0
@@ -146,7 +148,7 @@ VERSION    = str(MAJOR) + '.' + str(MINOR)
 IDENTIFIER = 'BSML ' + VERSION
 
 
-COMPRESSION = 'gzip'
+COMPRESSION = 'szip'                          #: Szip gives best performance
 
 DTYPE_STRING = h5py.special_dtype(vlen=str)   #: Store strings as variable length.
 
