@@ -18,6 +18,11 @@
 #
 ######################################################
 
+"""
+What this is about...
+
+"""
+
 import logging
 import json
 
@@ -35,6 +40,8 @@ import biosignalml.rdf.sparqlstore as sparqlstore
 
 import biosignalml.utils as utils
 
+__all__ = [ 'GraphStore', 'GraphUpdate' ]
+
 
 PROVENANCE_PATH = '/provenance'     #: Relative to a graph store's URI
 
@@ -121,24 +128,27 @@ class GraphStore(object):
     return DataItem.create_from_string(graph_uri, rdf, Format.RDFXML)
 
 
-  def get_resources(self, rtype, rvars='?r', condition='', group=None, prefixes=None, graph=None):
-  #-----------------------------------------------------------------------------------------------
+  def get_resources(self, rtype, rvars='?r', condition='',
+                                 group=None, prefixes=None, graph=None, order=None, resource=None):
+  #------------------------------------------------------------------------------------------------
     """
-    Find resources of the given type and the most recent graphs that
-    hold them.
+    Find resources of the given type and the most recent graphs that hold them.
 
     The resources found can be restricted by an optional SPARQL graph pattern.
 
     :param rtype: The type of resource to find. The SPARQL variable used for the
        resource is the first of the `rvars`.
-    :param rvars (str): Space separated SPARQL variables identifying the resource
+    :param str rvars: Space separated SPARQL variables identifying the resource
        in the query along with any other variables to return values of. The first variable
-       is usually that of the resource. Optional, defaults to `?r`.
-    :param condition (str): A SPARQL graph pattern for selecting resources. Optional.
-    :param group (str): Variables to group the results by. Optional.
-    :param prefixes (dict): Optional namespace prefixes for the SPARQL query.
+       is usually that of the resource. Optional, defaults to `?r` unless `resource` is given.
+    :param str condition: A SPARQL graph pattern for selecting resources. Optional.
+    :param str group: Variables to group the results by. Optional.
+    :param dict prefixes: Optional namespace prefixes for the SPARQL query.
     :param graph: The URI of a specific graph to search in, instead of finding
        the most recent. Optional.
+    :param str order: The sort order of the SPARQL query. Optional.
+    :param str resource: The SPARQL variable of the resource, if not in the `rvars` list.
+       Optional.
     :return: A list of (graph_uri, resource_uri, optional_variable) tuples.
     :rtype: list[tuple(:class:`~biosignalml.rdf.Uri`, :class:`~biosignalml.rdf.Uri`)]
     """
@@ -146,29 +156,30 @@ class GraphStore(object):
     if prefixes: pfxdict.update(prefixes)
     varlist = [ var for var in rvars.split() if var[0] == '?' ]
     retvars = [ var[1:] for var in varlist ]
+    if resource is None: resource = varlist[0]
     gv = sparqlstore.get_result_value   ## Shorten code
     NOVALUE = { 'value': None }  # For optional result variables
+    if order is None: order = ' '.join(varlist)
     if graph is None:
       return [ (gv(r, 'g'), gv(r, retvars[0])) + tuple([gv(r, v) for v in retvars[1:]])
         for r in self.select('?g %(rvars)s',
           '''graph <%(pgraph)s> { ?g a <%(gtype)s> MINUS { [] prv:precededBy ?g }}
              graph ?g { { %(res)s a <%(rtype)s> . %(cond)s } }''',
           params=dict(pgraph=self._provenance_uri, gtype=self._graphtype,
-                      res=varlist[0], rtype=rtype, rvars=rvars, cond=condition),
+                      res=resource, rtype=rtype, rvars=rvars, cond=condition),
           prefixes=pfxdict,
           group=group,
-          order='?g %s' % ' '.join(varlist))
+          order='?g %s' % order)
         ]
     else:
       return [ (Uri(str(graph)), gv(r, retvars[0])) + tuple([gv(r, v) for v in retvars[1:]])
         for r in self.select('%(rvars)s', '{ %(res)s a <%(rtype)s> . %(cond)s }',
-          params=dict(res=varlist[0], rtype=rtype, rvars=rvars, cond=condition),
+          params=dict(res=resource, rtype=rtype, rvars=rvars, cond=condition),
           prefixes=pfxdict,
           graph=graph,
-          order=' '.join(varlist))
+          order=order)
         ]
 
-
   def has_resource(self, uri, rtype=None, graph_uri=None):
   #-------------------------------------------------------
     '''
@@ -188,7 +199,6 @@ class GraphStore(object):
         params=dict(graph=graph_uri, uri=uri, rtype=rtype),
         prefixes=dict(prv=PRV.prefix))
 
-
   def has_graph(self, uri):
   #------------------------
     '''
@@ -197,6 +207,13 @@ class GraphStore(object):
     return self._sparqlstore.ask('graph <%(pgraph)s> { <%(uri)s> a <%(gtype)s> }',
       params=dict(pgraph=self._provenance_uri, uri=uri, gtype=self._graphtype))
 
+  def get_graph(self, graph_uri, rtype=None):
+  #------------------------------------------
+    rdf = self._sparqlstore.construct('?s ?p ?o', graph=graph_uri, format=Format.RDFXML)
+    ## Virtuoso has a MaxRows limit in its INI file with a default of 10000.
+    ## This has been increased to 50000
+    resource = Graph.create_from_string(graph_uri, rdf, Format.RDFXML)
+    return resource if rtype is None or resource.contains(Statement(None, RDF.type, rtype)) else None
 
   def get_resource_as_graph(self, uri, rtype, graph_uri=None):
   #-----------------------------------------------------------
@@ -205,19 +222,17 @@ class GraphStore(object):
       ### Following can give an error from Virtuoso...
       rdf = self._sparqlstore.construct('<%(uri)s> ?p ?o',
               '''graph <%(pgraph)s> { ?g a <%(gtype)s> MINUS { [] prv:precededBy ?g }}
-                 graph ?g { <%(uri)s> a <%(rtype)s> . <%(uri)s> ?p ?o }''',
+                 graph ?g { <%(uri)s> a <%(rtype)s> ; ?p ?o }''',
               params=dict(pgraph=self._provenance_uri, gtype=self._graphtype, uri=uri, rtype=rtype),
               prefixes=dict(prv=PRV.prefix), format=Format.RDFXML)
     else:
       rdf = self._sparqlstore.construct('<%(uri)s> ?p ?o',
-              'graph <%(graph)s> { <%(uri)s> a <%(rtype)s> . <%(uri)s> ?p ?o }',
-              params=dict(graph=graph_uri, uri=uri, rtype=rtype), format=Format.RDFXML)
-    ## Virtuoso has a MaxRows limit in its INI file with a default of 10000.
-    ## This has been increased to 50000
+              '<%(uri)s> a <%(rtype)s> ; ?p ?o',
+              params=dict(uri=uri, rtype=rtype),
+              graph=graph_uri, format=Format.RDFXML)
     resource = Graph.create_from_string(graph_uri, rdf, Format.RDFXML)
     return resource if resource.contains(Statement(uri, RDF.type, rtype)) else None
 
-
   def get_resource_graph_uri(self, uri):
   #-------------------------------------
     for r in self.select('?g',
@@ -227,14 +242,13 @@ class GraphStore(object):
         prefixes=dict(prv=PRV.prefix)):
       return sparqlstore.get_result_value(r, 'g')
 
-
   def query(self, sparql, header=False):
   #-------------------------------------
     return QueryResults(self._sparqlstore, sparql, header)
 
-#  def construct(self, template, where, params=None, graph=None, format=Format.RDFXML, prefixes=None):
-#  #--------------------------------------------------------------------------------------------------
-#    return self._sparqlstore.construct(template, where, params, graph, format, prefixes)
+  def construct(self, template, where=None, params=None, graph=None, format=Format.RDFXML, prefixes=None):
+  #-------------------------------------------------------------------------------------------------------
+    return self._sparqlstore.construct(template, where, params, graph, format, prefixes)
 
   def ask(self, query, graph):
   #---------------------------
