@@ -18,6 +18,10 @@
 #
 ######################################################
 
+### Documentation to include a generated list of units?
+### Or instructions on how to get such a list??
+### (abbreviation, URI (QName), description)
+
 import logging
 
 from biosignalml.rdf import Resource, NS
@@ -27,6 +31,9 @@ from ontology import UNITS
 # Export package class
 from convert import UnitConverter
 
+__all__ = [ 'get_units_uri' ]
+
+
 _direct = {
   'Bpm':    'BeatsPerMinute',
   'bpm':    'BeatsPerMinute',
