@@ -19,10 +19,15 @@
 ######################################################
 
 import pint
+import logging
 
 import biosignalml.rdf.sparqlstore as sparqlstore
 
 from biosignalml.rdf import NS, RDF, UOME
+
+__all__ = [ 'UnitConverter' ]
+
+
 UOME_CORE = NS('http://www.sbpax.org/uome/core.owl#')
 
 '''Graph holding http://www.sbpax.org/uome/core.owl#UnitOfMeasurement resources.'''
@@ -43,8 +48,8 @@ BASE_UNITS = { 'Metre':         'length',
              }
 
 
-def strip_prefix(uri):
-#=====================
+def _strip_prefix(uri):
+#======================
   for p in UNIT_PREFIXES:
     if uri.startswith(p): return(uri[len(p):])
   raise ValueError("'%s' doesn't have a standard unit prefix" % uri)
@@ -115,7 +120,7 @@ class UnitStore(object):
     uri = str(uri)
     unit = self._cache.get(uri)
     if unit is None:
-      name = strip_prefix(uri)
+      name = _strip_prefix(uri)
       if not self.contains(uri):
         raise KeyError("'%s' is not defined in units ontologies" % uri)
       derivation = self.get_derivation(uri)
@@ -169,7 +174,12 @@ class UnitConverter(object):
 if __name__ == '__main__':
 #=========================
 
-  store = UnitConverter(sparqlstore.Virtuoso('http://localhost:8890'))
+  import sys
+
+  logging.getLogger().setLevel(logging.DEBUG)
+
+  store = UnitConverter(sparqlstore.Virtuoso('http://polly.local:8890'))
+  #store = UnitConverter(sparqlstore.Virtuoso('http://localhost:8890'))
 
   def test(u):
   #-----------
